/*
 * FragmentResult.hpp
 *
 * Originally taken from my JobMarket project at 1.1.4.
 *
 *  Created on: Oct 19, 2011
 *      Author: heber
 */

#ifndef FRAGMENTRESULT_HPP_
#define FRAGMENTRESULT_HPP_

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif


#include <string>

#include <boost/shared_ptr.hpp>
#include <boost/serialization/array.hpp>
#include <boost/serialization/shared_ptr.hpp>

#ifdef HAVE_JOBMARKET
#include "JobMarket/JobId.hpp"
#include "JobMarket/types.hpp"
#else
#include "Jobs/JobMarket/JobId.hpp"
#include "Jobs/JobMarket/types.hpp"
#endif

class FragmentQueueTest;
class FragmentResultTest;

/** This class contains the result to a specific FragmentJob.
 *
 */
class FragmentResult : public JobId
{
  //!> allow FragmentQueue unit test access
  friend class FragmentQueueTest;
  //!> allow own unit test access
  friend class FragmentResultTest;
public:
  typedef boost::shared_ptr<FragmentResult> ptr;

  FragmentResult(const JobId_t id);
  FragmentResult(const JobId_t id, const std::string &_result);
  FragmentResult(const FragmentResult &other);
  ~FragmentResult();

  FragmentResult& operator=(const FragmentResult &other);
  bool operator==(const FragmentResult &other) const;
  bool operator!=(const FragmentResult &other) const
    { return !(*this == other); }

  //!> result
  std::string result;

  //!> exit flag
  int exitflag;

  //!> time needed for Work()
  double time_Work;

private:
  friend class boost::serialization::access;
  // this is new since boost 1.58 when deserializing vector<FragmentResult>
  friend class std::vector<FragmentResult, std::allocator<FragmentResult> >;

  /// private default constructor for serialization only.
  FragmentResult();

  // serialization
  template <typename Archive>
  void serialize(Archive& ar, const unsigned int version)
  {
    ar & boost::serialization::base_object<JobId>(*this);
    ar & result;
    ar & exitflag;
    ar & time_Work;
  }
};


#endif /* FRAGMENTRESULT_HPP_ */
